Jmbo Post
=========
**Jmbo post application. Post is a synonym for article. It is the most common content type.**

.. contents:: Contents
    :depth: 5

Content types
-------------

Post
****

Post introduces a single rich-text field called `Content`.

.. image:: https://raw.github.com/praekelt/jmbo-post/develop/images/admin.png

1.  Content is a rich-text field of arbitrary length.

.. figure:: https://raw.github.com/praekelt/jmbo-post/develop/images/post.png
    :align: center

    A post as it is seen by the public.

